#!/bin/bash

# ============LICENSE_START=======================================================
#  Copyright (C) 2019 The Nordix Foundation. All rights reserved.
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# SPDX-License-Identifier: Apache-2.0
# ============LICENSE_END=========================================================

set -o nounset
set -o errexit

if [[ "$EXECUTION_MODE" == "offline-deployment" ]]; then
  # ensure we delete leftovers due to lack of disk space
  sudo /bin/rm -rf /tmp/$ARTIFACT_TO_DOWNLOAD ~/.ara \
      /opt/engine /opt/test /opt/stack /httpboot > /dev/null 2>&1 || true
  sudo docker ps -a --format {{.ID}} | xargs -n 1 sudo docker stop > /dev/null 2>&1 || true
  sudo docker ps -a --format {{.ID}} | xargs -n 1 sudo docker rm > /dev/null 2>&1 || true
  sudo docker images -a --format {{.ID}} | xargs -n 1 sudo docker rmi -f > /dev/null 2>&1 || true
  sudo docker volume rm $(sudo docker volume ls -qf dangling=true) > /dev/null 2>&1 || true

  # offline nodes can't resolve artifactory.nordix.org
  echo "Info  : Offline deployment. Adding Nordix ARM Public IP to /etc/hosts"
  sudo bash -c "cat << EOF >> /etc/hosts
# managed by engine
$NORDIX_ARM_PUBLIC_IP artifactory.nordix.org
# managed by engine
EOF"
  echo "Info  : Downloading artifact from Nordix ARM..."
  echo "        $NORDIX_ARTIFACT_URL/$ARTIFACT_TO_DOWNLOAD"
  cd /tmp
  curl -s -O $NORDIX_ARTIFACT_URL/$ARTIFACT_TO_DOWNLOAD
  echo "Info  : Downloaded the artifact for offline deployment. Extracting..."
  echo "        $(ls -al /tmp/$ARTIFACT_TO_DOWNLOAD)"
  chmod +x /tmp/$ARTIFACT_TO_DOWNLOAD
  /tmp/$ARTIFACT_TO_DOWNLOAD
  sudo /bin/rm -rf /tmp/$ARTIFACT_TO_DOWNLOAD
else
  echo "Info  : Online deployment. Skipping artifact download."
fi
