#!/bin/bash

# ============LICENSE_START=======================================================
#  Copyright (C) 2019 The Nordix Foundation. All rights reserved.
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# SPDX-License-Identifier: Apache-2.0
# ============LICENSE_END=========================================================

set -o nounset
set -o errexit
set -o pipefail

if [[ "$EXECUTION_MODE" == "offline-deployment" ]]; then
  cd /tmp
  URL_TO_UPLOAD=$NORDIX_ARM_HTTPS_URL/$NORDIX_ARM_REPO/installer/oss/release/latest
  for ARTIFACT_TO_UPLOAD in $ARTIFACTS_TO_UPLOAD; do
    echo "Info  : Generating checksums for $ARTIFACT_TO_UPLOAD"
    ARTIFACT_MD5SUM=$(md5sum $ARTIFACT_TO_UPLOAD | cut -d' ' -f1)
    ARTIFACT_SHASUM=$(shasum $ARTIFACT_TO_UPLOAD | cut -d' ' -f1)
    ARTIFACT_SHA256SUM=$(sha256sum $ARTIFACT_TO_UPLOAD | cut -d' ' -f1)

    echo "Info  : Promoting $ARTIFACT_TO_UPLOAD"
    curl -s \
        -H "X-JFrog-Art-Api:$NORDIX_ARM_TOKEN" \
        -H "X-Checksum-MD5:$ARTIFACT_MD5SUM" \
        -H "X-Checksum-Sha1:$ARTIFACT_SHASUM" \
        -H "X-Checksum-Sha256:$ARTIFACT_SHA256SUM" \
        -T $ARTIFACT_TO_UPLOAD \
        "$URL_TO_UPLOAD/$ARTIFACT_TO_UPLOAD"
    echo "Info  : Artifact $ARTIFACT_TO_UPLOAD is available on $URL_TO_UPLOAD/$ARTIFACT_TO_UPLOAD"
  done
else
  echo "Info  : Online deployment. No artifact to upload."
fi
